/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service;

import aQute.bnd.annotation.ProviderType;

import com.liferay.exportimport.kernel.lar.PortletDataContext;

import com.liferay.portal.kernel.dao.orm.ActionableDynamicQuery;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.dao.orm.ExportActionableDynamicQuery;
import com.liferay.portal.kernel.dao.orm.IndexableActionableDynamicQuery;
import com.liferay.portal.kernel.dao.orm.Projection;
import com.liferay.portal.kernel.exception.NoSuchUserException;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.model.PersistedModel;
import com.liferay.portal.kernel.search.Indexable;
import com.liferay.portal.kernel.search.IndexableType;
import com.liferay.portal.kernel.service.BaseLocalService;
import com.liferay.portal.kernel.service.PersistedModelLocalService;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.transaction.Isolation;
import com.liferay.portal.kernel.transaction.Propagation;
import com.liferay.portal.kernel.transaction.Transactional;
import com.liferay.portal.kernel.util.OrderByComparator;

import fr.ippon.services.embercellar.model.Bottle;

import java.io.Serializable;

import java.util.List;

/**
 * Provides the local service interface for Bottle. Methods of this
 * service will not have security checks based on the propagated JAAS
 * credentials because this service can only be accessed from within the same
 * VM.
 *
 * @author Brian Wing Shun Chan
 * @see BottleLocalServiceUtil
 * @see fr.ippon.services.embercellar.service.base.BottleLocalServiceBaseImpl
 * @see fr.ippon.services.embercellar.service.impl.BottleLocalServiceImpl
 * @generated
 */
@ProviderType
@Transactional(isolation = Isolation.PORTAL, rollbackFor =  {
	PortalException.class, SystemException.class})
public interface BottleLocalService extends BaseLocalService,
	PersistedModelLocalService {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. Always use {@link BottleLocalServiceUtil} to access the bottle local service. Add custom service methods to {@link fr.ippon.services.embercellar.service.impl.BottleLocalServiceImpl} and rerun ServiceBuilder to automatically copy the method declarations to this interface.
	 */
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public ActionableDynamicQuery getActionableDynamicQuery();

	public DynamicQuery dynamicQuery();

	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public ExportActionableDynamicQuery getExportActionableDynamicQuery(
		PortletDataContext portletDataContext);

	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public IndexableActionableDynamicQuery getIndexableActionableDynamicQuery();

	/**
	* @throws PortalException
	*/
	@Override
	public PersistedModel deletePersistedModel(PersistedModel persistedModel)
		throws PortalException;

	@Override
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public PersistedModel getPersistedModel(Serializable primaryKeyObj)
		throws PortalException;

	/**
	* Adds the bottle to the database. Also notifies the appropriate model listeners.
	*
	* @param bottle the bottle
	* @return the bottle that was added
	*/
	@Indexable(type = IndexableType.REINDEX)
	public Bottle addBottle(Bottle bottle);

	public Bottle addBottle(long userId, long groupId, java.lang.String name,
		int column, int row, boolean flipped, long rackId,
		ServiceContext serviceContext) throws NoSuchUserException;

	/**
	* Creates a new bottle with the primary key. Does not add the bottle to the database.
	*
	* @param bottleId the primary key for the new bottle
	* @return the new bottle
	*/
	public Bottle createBottle(long bottleId);

	/**
	* Deletes the bottle from the database. Also notifies the appropriate model listeners.
	*
	* @param bottle the bottle
	* @return the bottle that was removed
	*/
	@Indexable(type = IndexableType.DELETE)
	public Bottle deleteBottle(Bottle bottle);

	/**
	* Deletes the bottle with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param bottleId the primary key of the bottle
	* @return the bottle that was removed
	* @throws PortalException if a bottle with the primary key could not be found
	*/
	@Indexable(type = IndexableType.DELETE)
	public Bottle deleteBottle(long bottleId) throws PortalException;

	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public Bottle fetchBottle(long bottleId);

	/**
	* Returns the bottle matching the UUID and group.
	*
	* @param uuid the bottle's UUID
	* @param groupId the primary key of the group
	* @return the matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public Bottle fetchBottleByUuidAndGroupId(java.lang.String uuid,
		long groupId);

	/**
	* Returns the bottle with the primary key.
	*
	* @param bottleId the primary key of the bottle
	* @return the bottle
	* @throws PortalException if a bottle with the primary key could not be found
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public Bottle getBottle(long bottleId) throws PortalException;

	/**
	* Returns the bottle matching the UUID and group.
	*
	* @param uuid the bottle's UUID
	* @param groupId the primary key of the group
	* @return the matching bottle
	* @throws PortalException if a matching bottle could not be found
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public Bottle getBottleByUuidAndGroupId(java.lang.String uuid, long groupId)
		throws PortalException;

	/**
	* Updates the bottle in the database or adds it if it does not yet exist. Also notifies the appropriate model listeners.
	*
	* @param bottle the bottle
	* @return the bottle that was updated
	*/
	@Indexable(type = IndexableType.REINDEX)
	public Bottle updateBottle(Bottle bottle);

	/**
	* Returns the number of bottles.
	*
	* @return the number of bottles
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public int getBottlesCount();

	/**
	* Returns the OSGi service identifier.
	*
	* @return the OSGi service identifier
	*/
	public java.lang.String getOSGiServiceIdentifier();

	/**
	* Performs a dynamic query on the database and returns the matching rows.
	*
	* @param dynamicQuery the dynamic query
	* @return the matching rows
	*/
	public <T> List<T> dynamicQuery(DynamicQuery dynamicQuery);

	/**
	* Performs a dynamic query on the database and returns a range of the matching rows.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link fr.ippon.services.embercellar.model.impl.BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param dynamicQuery the dynamic query
	* @param start the lower bound of the range of model instances
	* @param end the upper bound of the range of model instances (not inclusive)
	* @return the range of matching rows
	*/
	public <T> List<T> dynamicQuery(DynamicQuery dynamicQuery, int start,
		int end);

	/**
	* Performs a dynamic query on the database and returns an ordered range of the matching rows.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link fr.ippon.services.embercellar.model.impl.BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param dynamicQuery the dynamic query
	* @param start the lower bound of the range of model instances
	* @param end the upper bound of the range of model instances (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching rows
	*/
	public <T> List<T> dynamicQuery(DynamicQuery dynamicQuery, int start,
		int end, OrderByComparator<T> orderByComparator);

	public List<Bottle> findAll();

	/**
	* NOTE FOR DEVELOPERS:
	*
	* Never reference this class directly. Always use {@link fr.ippon.services.embercellar.service.BottleLocalServiceUtil} to access the bottle local service.
	*/
	public List<Bottle> findByRackId(long rackId);

	/**
	* Returns a range of all the bottles.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link fr.ippon.services.embercellar.model.impl.BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @return the range of bottles
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public List<Bottle> getBottles(int start, int end);

	/**
	* Returns all the bottles matching the UUID and company.
	*
	* @param uuid the UUID of the bottles
	* @param companyId the primary key of the company
	* @return the matching bottles, or an empty list if no matches were found
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public List<Bottle> getBottlesByUuidAndCompanyId(java.lang.String uuid,
		long companyId);

	/**
	* Returns a range of bottles matching the UUID and company.
	*
	* @param uuid the UUID of the bottles
	* @param companyId the primary key of the company
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the range of matching bottles, or an empty list if no matches were found
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public List<Bottle> getBottlesByUuidAndCompanyId(java.lang.String uuid,
		long companyId, int start, int end,
		OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the number of rows matching the dynamic query.
	*
	* @param dynamicQuery the dynamic query
	* @return the number of rows matching the dynamic query
	*/
	public long dynamicQueryCount(DynamicQuery dynamicQuery);

	/**
	* Returns the number of rows matching the dynamic query.
	*
	* @param dynamicQuery the dynamic query
	* @param projection the projection to apply to the query
	* @return the number of rows matching the dynamic query
	*/
	public long dynamicQueryCount(DynamicQuery dynamicQuery,
		Projection projection);
}