/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.persistence;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.service.persistence.BasePersistence;

import fr.ippon.services.embercellar.exception.NoSuchBottleException;
import fr.ippon.services.embercellar.model.Bottle;

/**
 * The persistence interface for the bottle service.
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see fr.ippon.services.embercellar.service.persistence.impl.BottlePersistenceImpl
 * @see BottleUtil
 * @generated
 */
@ProviderType
public interface BottlePersistence extends BasePersistence<Bottle> {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. Always use {@link BottleUtil} to access the bottle persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
	 */

	/**
	* Returns all the bottles where uuid = &#63;.
	*
	* @param uuid the uuid
	* @return the matching bottles
	*/
	public java.util.List<Bottle> findByUuid(java.lang.String uuid);

	/**
	* Returns a range of all the bottles where uuid = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @return the range of matching bottles
	*/
	public java.util.List<Bottle> findByUuid(java.lang.String uuid, int start,
		int end);

	/**
	* Returns an ordered range of all the bottles where uuid = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByUuid(java.lang.String uuid, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns an ordered range of all the bottles where uuid = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByUuid(java.lang.String uuid, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first bottle in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByUuid_First(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the first bottle in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByUuid_First(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the last bottle in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByUuid_Last(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the last bottle in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByUuid_Last(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the bottles before and after the current bottle in the ordered set where uuid = &#63;.
	*
	* @param bottleId the primary key of the current bottle
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next bottle
	* @throws NoSuchBottleException if a bottle with the primary key could not be found
	*/
	public Bottle[] findByUuid_PrevAndNext(long bottleId,
		java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Removes all the bottles where uuid = &#63; from the database.
	*
	* @param uuid the uuid
	*/
	public void removeByUuid(java.lang.String uuid);

	/**
	* Returns the number of bottles where uuid = &#63;.
	*
	* @param uuid the uuid
	* @return the number of matching bottles
	*/
	public int countByUuid(java.lang.String uuid);

	/**
	* Returns the bottle where uuid = &#63; and groupId = &#63; or throws a {@link NoSuchBottleException} if it could not be found.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByUUID_G(java.lang.String uuid, long groupId)
		throws NoSuchBottleException;

	/**
	* Returns the bottle where uuid = &#63; and groupId = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByUUID_G(java.lang.String uuid, long groupId);

	/**
	* Returns the bottle where uuid = &#63; and groupId = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByUUID_G(java.lang.String uuid, long groupId,
		boolean retrieveFromCache);

	/**
	* Removes the bottle where uuid = &#63; and groupId = &#63; from the database.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the bottle that was removed
	*/
	public Bottle removeByUUID_G(java.lang.String uuid, long groupId)
		throws NoSuchBottleException;

	/**
	* Returns the number of bottles where uuid = &#63; and groupId = &#63;.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the number of matching bottles
	*/
	public int countByUUID_G(java.lang.String uuid, long groupId);

	/**
	* Returns all the bottles where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @return the matching bottles
	*/
	public java.util.List<Bottle> findByUuid_C(java.lang.String uuid,
		long companyId);

	/**
	* Returns a range of all the bottles where uuid = &#63; and companyId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @return the range of matching bottles
	*/
	public java.util.List<Bottle> findByUuid_C(java.lang.String uuid,
		long companyId, int start, int end);

	/**
	* Returns an ordered range of all the bottles where uuid = &#63; and companyId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByUuid_C(java.lang.String uuid,
		long companyId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns an ordered range of all the bottles where uuid = &#63; and companyId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByUuid_C(java.lang.String uuid,
		long companyId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first bottle in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByUuid_C_First(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the first bottle in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByUuid_C_First(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the last bottle in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByUuid_C_Last(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the last bottle in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByUuid_C_Last(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the bottles before and after the current bottle in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param bottleId the primary key of the current bottle
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next bottle
	* @throws NoSuchBottleException if a bottle with the primary key could not be found
	*/
	public Bottle[] findByUuid_C_PrevAndNext(long bottleId,
		java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Removes all the bottles where uuid = &#63; and companyId = &#63; from the database.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	*/
	public void removeByUuid_C(java.lang.String uuid, long companyId);

	/**
	* Returns the number of bottles where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @return the number of matching bottles
	*/
	public int countByUuid_C(java.lang.String uuid, long companyId);

	/**
	* Returns all the bottles where name = &#63;.
	*
	* @param name the name
	* @return the matching bottles
	*/
	public java.util.List<Bottle> findByName(java.lang.String name);

	/**
	* Returns a range of all the bottles where name = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param name the name
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @return the range of matching bottles
	*/
	public java.util.List<Bottle> findByName(java.lang.String name, int start,
		int end);

	/**
	* Returns an ordered range of all the bottles where name = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param name the name
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByName(java.lang.String name, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns an ordered range of all the bottles where name = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param name the name
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByName(java.lang.String name, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first bottle in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByName_First(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the first bottle in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByName_First(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the last bottle in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByName_Last(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the last bottle in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByName_Last(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the bottles before and after the current bottle in the ordered set where name = &#63;.
	*
	* @param bottleId the primary key of the current bottle
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next bottle
	* @throws NoSuchBottleException if a bottle with the primary key could not be found
	*/
	public Bottle[] findByName_PrevAndNext(long bottleId,
		java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Removes all the bottles where name = &#63; from the database.
	*
	* @param name the name
	*/
	public void removeByName(java.lang.String name);

	/**
	* Returns the number of bottles where name = &#63;.
	*
	* @param name the name
	* @return the number of matching bottles
	*/
	public int countByName(java.lang.String name);

	/**
	* Returns all the bottles where rackId = &#63;.
	*
	* @param rackId the rack ID
	* @return the matching bottles
	*/
	public java.util.List<Bottle> findByRackId(long rackId);

	/**
	* Returns a range of all the bottles where rackId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param rackId the rack ID
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @return the range of matching bottles
	*/
	public java.util.List<Bottle> findByRackId(long rackId, int start, int end);

	/**
	* Returns an ordered range of all the bottles where rackId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param rackId the rack ID
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByRackId(long rackId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns an ordered range of all the bottles where rackId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param rackId the rack ID
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching bottles
	*/
	public java.util.List<Bottle> findByRackId(long rackId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first bottle in the ordered set where rackId = &#63;.
	*
	* @param rackId the rack ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByRackId_First(long rackId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the first bottle in the ordered set where rackId = &#63;.
	*
	* @param rackId the rack ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByRackId_First(long rackId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the last bottle in the ordered set where rackId = &#63;.
	*
	* @param rackId the rack ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle
	* @throws NoSuchBottleException if a matching bottle could not be found
	*/
	public Bottle findByRackId_Last(long rackId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Returns the last bottle in the ordered set where rackId = &#63;.
	*
	* @param rackId the rack ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching bottle, or <code>null</code> if a matching bottle could not be found
	*/
	public Bottle fetchByRackId_Last(long rackId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns the bottles before and after the current bottle in the ordered set where rackId = &#63;.
	*
	* @param bottleId the primary key of the current bottle
	* @param rackId the rack ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next bottle
	* @throws NoSuchBottleException if a bottle with the primary key could not be found
	*/
	public Bottle[] findByRackId_PrevAndNext(long bottleId, long rackId,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator)
		throws NoSuchBottleException;

	/**
	* Removes all the bottles where rackId = &#63; from the database.
	*
	* @param rackId the rack ID
	*/
	public void removeByRackId(long rackId);

	/**
	* Returns the number of bottles where rackId = &#63;.
	*
	* @param rackId the rack ID
	* @return the number of matching bottles
	*/
	public int countByRackId(long rackId);

	/**
	* Caches the bottle in the entity cache if it is enabled.
	*
	* @param bottle the bottle
	*/
	public void cacheResult(Bottle bottle);

	/**
	* Caches the bottles in the entity cache if it is enabled.
	*
	* @param bottles the bottles
	*/
	public void cacheResult(java.util.List<Bottle> bottles);

	/**
	* Creates a new bottle with the primary key. Does not add the bottle to the database.
	*
	* @param bottleId the primary key for the new bottle
	* @return the new bottle
	*/
	public Bottle create(long bottleId);

	/**
	* Removes the bottle with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param bottleId the primary key of the bottle
	* @return the bottle that was removed
	* @throws NoSuchBottleException if a bottle with the primary key could not be found
	*/
	public Bottle remove(long bottleId) throws NoSuchBottleException;

	public Bottle updateImpl(Bottle bottle);

	/**
	* Returns the bottle with the primary key or throws a {@link NoSuchBottleException} if it could not be found.
	*
	* @param bottleId the primary key of the bottle
	* @return the bottle
	* @throws NoSuchBottleException if a bottle with the primary key could not be found
	*/
	public Bottle findByPrimaryKey(long bottleId) throws NoSuchBottleException;

	/**
	* Returns the bottle with the primary key or returns <code>null</code> if it could not be found.
	*
	* @param bottleId the primary key of the bottle
	* @return the bottle, or <code>null</code> if a bottle with the primary key could not be found
	*/
	public Bottle fetchByPrimaryKey(long bottleId);

	@Override
	public java.util.Map<java.io.Serializable, Bottle> fetchByPrimaryKeys(
		java.util.Set<java.io.Serializable> primaryKeys);

	/**
	* Returns all the bottles.
	*
	* @return the bottles
	*/
	public java.util.List<Bottle> findAll();

	/**
	* Returns a range of all the bottles.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @return the range of bottles
	*/
	public java.util.List<Bottle> findAll(int start, int end);

	/**
	* Returns an ordered range of all the bottles.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of bottles
	*/
	public java.util.List<Bottle> findAll(int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator);

	/**
	* Returns an ordered range of all the bottles.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link BottleModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of bottles
	* @param end the upper bound of the range of bottles (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of bottles
	*/
	public java.util.List<Bottle> findAll(int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Bottle> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Removes all the bottles from the database.
	*/
	public void removeAll();

	/**
	* Returns the number of bottles.
	*
	* @return the number of bottles
	*/
	public int countAll();

	@Override
	public java.util.Set<java.lang.String> getBadColumnNames();
}