/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.persistence;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.service.persistence.BasePersistence;

import fr.ippon.services.embercellar.exception.NoSuchRackException;
import fr.ippon.services.embercellar.model.Rack;

/**
 * The persistence interface for the rack service.
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see fr.ippon.services.embercellar.service.persistence.impl.RackPersistenceImpl
 * @see RackUtil
 * @generated
 */
@ProviderType
public interface RackPersistence extends BasePersistence<Rack> {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. Always use {@link RackUtil} to access the rack persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
	 */

	/**
	* Returns all the racks where uuid = &#63;.
	*
	* @param uuid the uuid
	* @return the matching racks
	*/
	public java.util.List<Rack> findByUuid(java.lang.String uuid);

	/**
	* Returns a range of all the racks where uuid = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @return the range of matching racks
	*/
	public java.util.List<Rack> findByUuid(java.lang.String uuid, int start,
		int end);

	/**
	* Returns an ordered range of all the racks where uuid = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching racks
	*/
	public java.util.List<Rack> findByUuid(java.lang.String uuid, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns an ordered range of all the racks where uuid = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching racks
	*/
	public java.util.List<Rack> findByUuid(java.lang.String uuid, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first rack in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByUuid_First(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Returns the first rack in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByUuid_First(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns the last rack in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByUuid_Last(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Returns the last rack in the ordered set where uuid = &#63;.
	*
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByUuid_Last(java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns the racks before and after the current rack in the ordered set where uuid = &#63;.
	*
	* @param rackId the primary key of the current rack
	* @param uuid the uuid
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next rack
	* @throws NoSuchRackException if a rack with the primary key could not be found
	*/
	public Rack[] findByUuid_PrevAndNext(long rackId, java.lang.String uuid,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Removes all the racks where uuid = &#63; from the database.
	*
	* @param uuid the uuid
	*/
	public void removeByUuid(java.lang.String uuid);

	/**
	* Returns the number of racks where uuid = &#63;.
	*
	* @param uuid the uuid
	* @return the number of matching racks
	*/
	public int countByUuid(java.lang.String uuid);

	/**
	* Returns the rack where uuid = &#63; and groupId = &#63; or throws a {@link NoSuchRackException} if it could not be found.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByUUID_G(java.lang.String uuid, long groupId)
		throws NoSuchRackException;

	/**
	* Returns the rack where uuid = &#63; and groupId = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByUUID_G(java.lang.String uuid, long groupId);

	/**
	* Returns the rack where uuid = &#63; and groupId = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByUUID_G(java.lang.String uuid, long groupId,
		boolean retrieveFromCache);

	/**
	* Removes the rack where uuid = &#63; and groupId = &#63; from the database.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the rack that was removed
	*/
	public Rack removeByUUID_G(java.lang.String uuid, long groupId)
		throws NoSuchRackException;

	/**
	* Returns the number of racks where uuid = &#63; and groupId = &#63;.
	*
	* @param uuid the uuid
	* @param groupId the group ID
	* @return the number of matching racks
	*/
	public int countByUUID_G(java.lang.String uuid, long groupId);

	/**
	* Returns all the racks where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @return the matching racks
	*/
	public java.util.List<Rack> findByUuid_C(java.lang.String uuid,
		long companyId);

	/**
	* Returns a range of all the racks where uuid = &#63; and companyId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @return the range of matching racks
	*/
	public java.util.List<Rack> findByUuid_C(java.lang.String uuid,
		long companyId, int start, int end);

	/**
	* Returns an ordered range of all the racks where uuid = &#63; and companyId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching racks
	*/
	public java.util.List<Rack> findByUuid_C(java.lang.String uuid,
		long companyId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns an ordered range of all the racks where uuid = &#63; and companyId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching racks
	*/
	public java.util.List<Rack> findByUuid_C(java.lang.String uuid,
		long companyId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first rack in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByUuid_C_First(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Returns the first rack in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByUuid_C_First(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns the last rack in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByUuid_C_Last(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Returns the last rack in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByUuid_C_Last(java.lang.String uuid, long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns the racks before and after the current rack in the ordered set where uuid = &#63; and companyId = &#63;.
	*
	* @param rackId the primary key of the current rack
	* @param uuid the uuid
	* @param companyId the company ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next rack
	* @throws NoSuchRackException if a rack with the primary key could not be found
	*/
	public Rack[] findByUuid_C_PrevAndNext(long rackId, java.lang.String uuid,
		long companyId,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Removes all the racks where uuid = &#63; and companyId = &#63; from the database.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	*/
	public void removeByUuid_C(java.lang.String uuid, long companyId);

	/**
	* Returns the number of racks where uuid = &#63; and companyId = &#63;.
	*
	* @param uuid the uuid
	* @param companyId the company ID
	* @return the number of matching racks
	*/
	public int countByUuid_C(java.lang.String uuid, long companyId);

	/**
	* Returns all the racks where name = &#63;.
	*
	* @param name the name
	* @return the matching racks
	*/
	public java.util.List<Rack> findByName(java.lang.String name);

	/**
	* Returns a range of all the racks where name = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param name the name
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @return the range of matching racks
	*/
	public java.util.List<Rack> findByName(java.lang.String name, int start,
		int end);

	/**
	* Returns an ordered range of all the racks where name = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param name the name
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching racks
	*/
	public java.util.List<Rack> findByName(java.lang.String name, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns an ordered range of all the racks where name = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param name the name
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of matching racks
	*/
	public java.util.List<Rack> findByName(java.lang.String name, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Returns the first rack in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByName_First(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Returns the first rack in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByName_First(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns the last rack in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching rack
	* @throws NoSuchRackException if a matching rack could not be found
	*/
	public Rack findByName_Last(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Returns the last rack in the ordered set where name = &#63;.
	*
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching rack, or <code>null</code> if a matching rack could not be found
	*/
	public Rack fetchByName_Last(java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns the racks before and after the current rack in the ordered set where name = &#63;.
	*
	* @param rackId the primary key of the current rack
	* @param name the name
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next rack
	* @throws NoSuchRackException if a rack with the primary key could not be found
	*/
	public Rack[] findByName_PrevAndNext(long rackId, java.lang.String name,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator)
		throws NoSuchRackException;

	/**
	* Removes all the racks where name = &#63; from the database.
	*
	* @param name the name
	*/
	public void removeByName(java.lang.String name);

	/**
	* Returns the number of racks where name = &#63;.
	*
	* @param name the name
	* @return the number of matching racks
	*/
	public int countByName(java.lang.String name);

	/**
	* Caches the rack in the entity cache if it is enabled.
	*
	* @param rack the rack
	*/
	public void cacheResult(Rack rack);

	/**
	* Caches the racks in the entity cache if it is enabled.
	*
	* @param racks the racks
	*/
	public void cacheResult(java.util.List<Rack> racks);

	/**
	* Creates a new rack with the primary key. Does not add the rack to the database.
	*
	* @param rackId the primary key for the new rack
	* @return the new rack
	*/
	public Rack create(long rackId);

	/**
	* Removes the rack with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param rackId the primary key of the rack
	* @return the rack that was removed
	* @throws NoSuchRackException if a rack with the primary key could not be found
	*/
	public Rack remove(long rackId) throws NoSuchRackException;

	public Rack updateImpl(Rack rack);

	/**
	* Returns the rack with the primary key or throws a {@link NoSuchRackException} if it could not be found.
	*
	* @param rackId the primary key of the rack
	* @return the rack
	* @throws NoSuchRackException if a rack with the primary key could not be found
	*/
	public Rack findByPrimaryKey(long rackId) throws NoSuchRackException;

	/**
	* Returns the rack with the primary key or returns <code>null</code> if it could not be found.
	*
	* @param rackId the primary key of the rack
	* @return the rack, or <code>null</code> if a rack with the primary key could not be found
	*/
	public Rack fetchByPrimaryKey(long rackId);

	@Override
	public java.util.Map<java.io.Serializable, Rack> fetchByPrimaryKeys(
		java.util.Set<java.io.Serializable> primaryKeys);

	/**
	* Returns all the racks.
	*
	* @return the racks
	*/
	public java.util.List<Rack> findAll();

	/**
	* Returns a range of all the racks.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @return the range of racks
	*/
	public java.util.List<Rack> findAll(int start, int end);

	/**
	* Returns an ordered range of all the racks.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of racks
	*/
	public java.util.List<Rack> findAll(int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator);

	/**
	* Returns an ordered range of all the racks.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link RackModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of racks
	* @param end the upper bound of the range of racks (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of racks
	*/
	public java.util.List<Rack> findAll(int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<Rack> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Removes all the racks from the database.
	*/
	public void removeAll();

	/**
	* Returns the number of racks.
	*
	* @return the number of racks
	*/
	public int countAll();

	@Override
	public java.util.Set<java.lang.String> getBadColumnNames();
}