/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.model.impl;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.model.CacheModel;
import com.liferay.portal.kernel.util.HashUtil;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringPool;

import fr.ippon.services.embercellar.model.Rack;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import java.util.Date;

/**
 * The cache model class for representing Rack in entity cache.
 *
 * @author Brian Wing Shun Chan
 * @see Rack
 * @generated
 */
@ProviderType
public class RackCacheModel implements CacheModel<Rack>, Externalizable {
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}

		if (!(obj instanceof RackCacheModel)) {
			return false;
		}

		RackCacheModel rackCacheModel = (RackCacheModel)obj;

		if (rackId == rackCacheModel.rackId) {
			return true;
		}

		return false;
	}

	@Override
	public int hashCode() {
		return HashUtil.hash(0, rackId);
	}

	@Override
	public String toString() {
		StringBundler sb = new StringBundler(29);

		sb.append("{uuid=");
		sb.append(uuid);
		sb.append(", rackId=");
		sb.append(rackId);
		sb.append(", groupId=");
		sb.append(groupId);
		sb.append(", companyId=");
		sb.append(companyId);
		sb.append(", userId=");
		sb.append(userId);
		sb.append(", userName=");
		sb.append(userName);
		sb.append(", createDate=");
		sb.append(createDate);
		sb.append(", modifiedDate=");
		sb.append(modifiedDate);
		sb.append(", type=");
		sb.append(type);
		sb.append(", name=");
		sb.append(name);
		sb.append(", nbColumns=");
		sb.append(nbColumns);
		sb.append(", nbRows=");
		sb.append(nbRows);
		sb.append(", image=");
		sb.append(image);
		sb.append(", bottlesId=");
		sb.append(bottlesId);
		sb.append("}");

		return sb.toString();
	}

	@Override
	public Rack toEntityModel() {
		RackImpl rackImpl = new RackImpl();

		if (uuid == null) {
			rackImpl.setUuid(StringPool.BLANK);
		}
		else {
			rackImpl.setUuid(uuid);
		}

		rackImpl.setRackId(rackId);
		rackImpl.setGroupId(groupId);
		rackImpl.setCompanyId(companyId);
		rackImpl.setUserId(userId);

		if (userName == null) {
			rackImpl.setUserName(StringPool.BLANK);
		}
		else {
			rackImpl.setUserName(userName);
		}

		if (createDate == Long.MIN_VALUE) {
			rackImpl.setCreateDate(null);
		}
		else {
			rackImpl.setCreateDate(new Date(createDate));
		}

		if (modifiedDate == Long.MIN_VALUE) {
			rackImpl.setModifiedDate(null);
		}
		else {
			rackImpl.setModifiedDate(new Date(modifiedDate));
		}

		if (type == null) {
			rackImpl.setType(StringPool.BLANK);
		}
		else {
			rackImpl.setType(type);
		}

		if (name == null) {
			rackImpl.setName(StringPool.BLANK);
		}
		else {
			rackImpl.setName(name);
		}

		rackImpl.setNbColumns(nbColumns);
		rackImpl.setNbRows(nbRows);

		if (image == null) {
			rackImpl.setImage(StringPool.BLANK);
		}
		else {
			rackImpl.setImage(image);
		}

		if (bottlesId == null) {
			rackImpl.setBottlesId(StringPool.BLANK);
		}
		else {
			rackImpl.setBottlesId(bottlesId);
		}

		rackImpl.resetOriginalValues();

		return rackImpl;
	}

	@Override
	public void readExternal(ObjectInput objectInput) throws IOException {
		uuid = objectInput.readUTF();

		rackId = objectInput.readLong();

		groupId = objectInput.readLong();

		companyId = objectInput.readLong();

		userId = objectInput.readLong();
		userName = objectInput.readUTF();
		createDate = objectInput.readLong();
		modifiedDate = objectInput.readLong();
		type = objectInput.readUTF();
		name = objectInput.readUTF();

		nbColumns = objectInput.readInt();

		nbRows = objectInput.readInt();
		image = objectInput.readUTF();
		bottlesId = objectInput.readUTF();
	}

	@Override
	public void writeExternal(ObjectOutput objectOutput)
		throws IOException {
		if (uuid == null) {
			objectOutput.writeUTF(StringPool.BLANK);
		}
		else {
			objectOutput.writeUTF(uuid);
		}

		objectOutput.writeLong(rackId);

		objectOutput.writeLong(groupId);

		objectOutput.writeLong(companyId);

		objectOutput.writeLong(userId);

		if (userName == null) {
			objectOutput.writeUTF(StringPool.BLANK);
		}
		else {
			objectOutput.writeUTF(userName);
		}

		objectOutput.writeLong(createDate);
		objectOutput.writeLong(modifiedDate);

		if (type == null) {
			objectOutput.writeUTF(StringPool.BLANK);
		}
		else {
			objectOutput.writeUTF(type);
		}

		if (name == null) {
			objectOutput.writeUTF(StringPool.BLANK);
		}
		else {
			objectOutput.writeUTF(name);
		}

		objectOutput.writeInt(nbColumns);

		objectOutput.writeInt(nbRows);

		if (image == null) {
			objectOutput.writeUTF(StringPool.BLANK);
		}
		else {
			objectOutput.writeUTF(image);
		}

		if (bottlesId == null) {
			objectOutput.writeUTF(StringPool.BLANK);
		}
		else {
			objectOutput.writeUTF(bottlesId);
		}
	}

	public String uuid;
	public long rackId;
	public long groupId;
	public long companyId;
	public long userId;
	public String userName;
	public long createDate;
	public long modifiedDate;
	public String type;
	public String name;
	public int nbColumns;
	public int nbRows;
	public String image;
	public String bottlesId;
}