/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.http;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.security.auth.HttpPrincipal;
import com.liferay.portal.kernel.service.http.TunnelUtil;
import com.liferay.portal.kernel.util.MethodHandler;
import com.liferay.portal.kernel.util.MethodKey;

import fr.ippon.services.embercellar.service.RackServiceUtil;

/**
 * Provides the HTTP utility for the
 * {@link RackServiceUtil} service utility. The
 * static methods of this class calls the same methods of the service utility.
 * However, the signatures are different because it requires an additional
 * {@link HttpPrincipal} parameter.
 *
 * <p>
 * The benefits of using the HTTP utility is that it is fast and allows for
 * tunneling without the cost of serializing to text. The drawback is that it
 * only works with Java.
 * </p>
 *
 * <p>
 * Set the property <b>tunnel.servlet.hosts.allowed</b> in portal.properties to
 * configure security.
 * </p>
 *
 * <p>
 * The HTTP utility is only generated for remote services.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see RackServiceSoap
 * @see HttpPrincipal
 * @see RackServiceUtil
 * @generated
 */
@ProviderType
public class RackServiceHttp {
	public static fr.ippon.services.embercellar.model.Rack addRack(
		HttpPrincipal httpPrincipal, java.lang.String name, int nbColumns,
		int nbRows, java.lang.String pathImg,
		com.liferay.portal.kernel.service.ServiceContext serviceContext) {
		try {
			MethodKey methodKey = new MethodKey(RackServiceUtil.class,
					"addRack", _addRackParameterTypes0);

			MethodHandler methodHandler = new MethodHandler(methodKey, name,
					nbColumns, nbRows, pathImg, serviceContext);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				throw new com.liferay.portal.kernel.exception.SystemException(e);
			}

			return (fr.ippon.services.embercellar.model.Rack)returnObj;
		}
		catch (com.liferay.portal.kernel.exception.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static java.util.List<fr.ippon.services.embercellar.model.Rack> findAll(
		HttpPrincipal httpPrincipal) {
		try {
			MethodKey methodKey = new MethodKey(RackServiceUtil.class,
					"findAll", _findAllParameterTypes1);

			MethodHandler methodHandler = new MethodHandler(methodKey);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				throw new com.liferay.portal.kernel.exception.SystemException(e);
			}

			return (java.util.List<fr.ippon.services.embercellar.model.Rack>)returnObj;
		}
		catch (com.liferay.portal.kernel.exception.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static fr.ippon.services.embercellar.model.Rack findByRackId(
		HttpPrincipal httpPrincipal, long rackId) {
		try {
			MethodKey methodKey = new MethodKey(RackServiceUtil.class,
					"findByRackId", _findByRackIdParameterTypes2);

			MethodHandler methodHandler = new MethodHandler(methodKey, rackId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				throw new com.liferay.portal.kernel.exception.SystemException(e);
			}

			return (fr.ippon.services.embercellar.model.Rack)returnObj;
		}
		catch (com.liferay.portal.kernel.exception.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	private static Log _log = LogFactoryUtil.getLog(RackServiceHttp.class);
	private static final Class<?>[] _addRackParameterTypes0 = new Class[] {
			java.lang.String.class, int.class, int.class, java.lang.String.class,
			com.liferay.portal.kernel.service.ServiceContext.class
		};
	private static final Class<?>[] _findAllParameterTypes1 = new Class[] {  };
	private static final Class<?>[] _findByRackIdParameterTypes2 = new Class[] {
			long.class
		};
}