/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.impl;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.exception.NoSuchUserException;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.service.ServiceContext;

import fr.ippon.services.embercellar.model.Bottle;
import fr.ippon.services.embercellar.service.base.BottleLocalServiceBaseImpl;

import java.util.Date;
import java.util.List;

/**
 * The implementation of the bottle local service.
 *
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun ServiceBuilder to copy their definitions into the {@link fr.ippon.services.embercellar.service.BottleLocalService} interface.
 *
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see BottleLocalServiceBaseImpl
 * @see fr.ippon.services.embercellar.service.BottleLocalServiceUtil
 */
@ProviderType
public class BottleLocalServiceImpl extends BottleLocalServiceBaseImpl {

	public Bottle addBottle(long userId, long groupId,
							String name, int column, int row, boolean flipped,
							long rackId,
							ServiceContext serviceContext) throws NoSuchUserException {

		User user = userPersistence.findByPrimaryKey(userId);
		Date now = new Date();

		long bottleId = counterLocalService.increment(Bottle.class.getName());
		Bottle bottle = bottlePersistence.create(bottleId);

		bottle.setUserId(userId);
		bottle.setGroupId(groupId);
		bottle.setCompanyId(user.getCompanyId());
		bottle.setCreateDate(serviceContext.getCreateDate(now));
		bottle.setModifiedDate(serviceContext.getModifiedDate(now));
		bottle.setName(name);
		bottle.setXcolumn(column);
		bottle.setYrow(row);
		bottle.setFlipped(flipped);
		bottle.setRackId(rackId);

		super.addBottle(bottle);

		return bottle;
	}

	/**
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never reference this class directly. Always use {@link fr.ippon.services.embercellar.service.BottleLocalServiceUtil} to access the bottle local service.
	 */

	public List<Bottle> findByRackId(long rackId) {
		return bottlePersistence.findByRackId(rackId);
	}

	public List<Bottle> findAll() {
		return bottlePersistence.findAll();
	}
}
