/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.impl;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.exception.NoSuchUserException;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.service.ServiceContext;

import fr.ippon.services.embercellar.model.Bottle;
import fr.ippon.services.embercellar.service.base.BottleServiceBaseImpl;

import java.util.List;

/**
 * The implementation of the bottle remote service.
 *
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun ServiceBuilder to copy their definitions into the {@link fr.ippon.services.embercellar.service.BottleService} interface.
 *
 * <p>
 * This is a remote service. Methods of this service are expected to have security checks based on the propagated JAAS credentials because this service can be accessed remotely.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see BottleServiceBaseImpl
 * @see fr.ippon.services.embercellar.service.BottleServiceUtil
 */
@ProviderType
public class BottleServiceImpl extends BottleServiceBaseImpl {
	private static Log _log = LogFactoryUtil.getLog(BottleServiceImpl.class);

	/**
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never reference this class directly. Always use {@link fr.ippon.services.embercellar.service.BottleServiceUtil} to access the bottle remote service.
	 */
	public Bottle addBottle(
			String name, int column, int row, boolean flipped, long rackId,
			ServiceContext serviceContext)
		throws NoSuchUserException {

		User user = null;

		try {
			user = userLocalService.getUser(this.getUserId());
			long groupId = user.getGroupId();
			return bottleLocalService.addBottle(
				this.getUserId(), groupId, name, column, row, flipped, rackId,
				serviceContext);

		} catch (PortalException e) {
			e.printStackTrace();
			return null;
		}
	}

	public Bottle findByBottleId(long bottleId) {
		try {
			return bottleLocalService.getBottle(bottleId);
		} catch (PortalException e) {
			return null;
		}
	}

	public List<Bottle> findByRackId(long rackId) {
		return bottleLocalService.findByRackId(rackId);
	}


	public List<Bottle> findAll() {
		return bottleLocalService.findAll();
	}
}
