/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.impl;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.exception.NoSuchUserException;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.service.ServiceContext;

import fr.ippon.services.embercellar.exception.NoSuchRackException;
import fr.ippon.services.embercellar.model.Rack;
import fr.ippon.services.embercellar.service.base.RackLocalServiceBaseImpl;

import java.util.Date;
import java.util.List;

/**
 * The implementation of the rack local service.
 *
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun ServiceBuilder to copy their definitions into the {@link fr.ippon.services.embercellar.service.RackLocalService} interface.
 *
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see RackLocalServiceBaseImpl
 * @see fr.ippon.services.embercellar.service.RackLocalServiceUtil
 */
@ProviderType
public class RackLocalServiceImpl extends RackLocalServiceBaseImpl {

	public Rack addRack(long userId, long groupId,
						String name, int nbColumns, int nbRows, String pathImg,
						ServiceContext serviceContext) throws NoSuchUserException {

		User user = userPersistence.findByPrimaryKey(userId);
		Date now = new Date();

		long rackId = counterLocalService.increment(Rack.class.getName());
		Rack rack = rackPersistence.create(rackId);

		rack.setUserId(userId);
		rack.setCompanyId(user.getCompanyId());
		rack.setGroupId(groupId);
		rack.setCreateDate(serviceContext.getCreateDate(now));
		rack.setModifiedDate(serviceContext.getModifiedDate(now));
		rack.setName(name);
		rack.setNbColumns(nbColumns);
		rack.setNbRows(nbRows);
		rack.setImage(pathImg);

		super.addRack(rack);

		return rack;
	}

	/**
	 * NOTE FOR DEVELOPERS:
	 * <p/>
	 * Never reference this class directly. Always use {@link fr.ippon.services.embercellar.service.RackLocalServiceUtil} to access the rack local service.
	 */
	public List<Rack> findAll() {
		return rackPersistence.findAll();
	}

	public Rack findByRackId(long rackId) {
		try {
			Rack rack = rackPersistence.findByPrimaryKey(rackId);
			return rack;
		} catch (NoSuchRackException e) {
			e.printStackTrace();
			return null;
		}
	}

}
