/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package fr.ippon.services.embercellar.service.impl;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.service.ServiceContext;

import fr.ippon.services.embercellar.model.Bottle;
import fr.ippon.services.embercellar.model.Rack;
import fr.ippon.services.embercellar.service.base.RackServiceBaseImpl;

import java.util.ArrayList;
import java.util.List;

/**
 * The implementation of the rack remote service.
 *
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun ServiceBuilder to copy their definitions into the {@link fr.ippon.services.embercellar.service.RackService} interface.
 *
 * <p>
 * This is a remote service. Methods of this service are expected to have security checks based on the propagated JAAS credentials because this service can be accessed remotely.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see RackServiceBaseImpl
 * @see fr.ippon.services.embercellar.service.RackServiceUtil
 */
@ProviderType
public class RackServiceImpl extends RackServiceBaseImpl {

	public Rack addRack(
		String name, int nbColumns, int nbRows, String pathImg,
		ServiceContext serviceContext) {

		try {
			User user = userLocalService.getUser(this.getUserId());

			long groupId = user.getGroupId();
			return rackLocalService.addRack(
				this.getUserId(), groupId, name, nbColumns, nbRows, pathImg,
				serviceContext);
		} catch (PortalException e) {
			e.printStackTrace();
			return null;
		}
	}

	/**
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never reference this class directly. Always use {@link fr.ippon.services.embercellar.service.RackServiceUtil} to access the rack remote service.
	 */
	public List<Rack> findAll() {
		return rackLocalService.findAll();
	}

	public Rack findByRackId(long rackId) {
		Rack rack = rackLocalService.findByRackId(rackId);

		List<Bottle> bottles = bottleLocalService.findByRackId(rackId);
		List<Long> bottleIds = new ArrayList<>();

		for (Bottle bottle : bottles)
			bottleIds.add(bottle.getBottleId());

		rack.setBottlesId(bottleIds.toString());

		return rack;
	}

}
